# DataLines

A package to prevent reinventing the wheel every time data needs to be loaded or processed. Aims at operating with the least number of dependencies (for high compatibility and lightweight).

## Table of contents

- [DataLines](#datalines)
    - [Table of contents](#table-of-contents)
    - [Docs](#docs)
    - [Contents](#contents)
    - [References](#references)

## Docs

Package documentation resources are listed below

- [datalines](./src/datalines/README.md) package

## Contents

The contents of this folder are described below

| Item Name | Description |
| :---- | :----- |
| [LICENSE](./LICENSE) | License: `GNU LGPL v3` |
| [pyproject.toml](./pyproject.toml) | Project build system |
| [setup.py](./setup.py) | Project metadata |
| [conda-env-full.yml](./conda-env-full.yml) | Anaconda environment (for development and build systems) |
| [src](./src/README.md) folder | The main source code |

## References

- Packaging Python projects: [packaging.python.org](https://packaging.python.org/en/latest/tutorials/packaging-projects/)
- Project page on [PyPI](https://pypi.org/project/datalines/)
